@@ -426,7 +426,7 @@ SEXP call_fit_collective_explicit_als
         (bool) Rf_asLogical(handle_interrupt),
         (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps),
         (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
-        (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
+        (bool) Rf_asLogical(nonneg), Rf_asInteger(max_cd_steps),
         nonneg_C, nonneg_D,
         (bool) Rf_asLogical(precompute),
         (bool) Rf_asLogical(include_all_X),
@@ -517,7 +517,7 @@ SEXP call_fit_collective_implicit_als
         (bool) Rf_asLogical(handle_interrupt),
         (bool) Rf_asLogical(use_cg), Rf_asInteger(max_cg_steps),
         (bool) Rf_asLogical(precondition_cg), (bool) Rf_asLogical(finalize_chol),
-        (bool) Rf_asLogical(nonneg), (size_t) Rf_asInteger(max_cd_steps),
+        (bool) Rf_asLogical(nonneg), Rf_asInteger(max_cd_steps),
         (bool) Rf_asLogical(nonneg_C), (bool) Rf_asLogical(nonneg_D),
         (bool) Rf_asLogical(precompute),
         get_ptr(BtB),
